PagamentoResult class

Constructors

PagamentoResult({required String cardBrand, required String cardBin, required String nsu, required String date, required String time, required String hostNSU, required String transactionID, required String transactionCode})
PagamentoResult.erro({required String? erro})

Properties

cardBin String
final
cardBrand String
final
date String
final
erro String?
final
hashCode int
The hash code for this object.
no setterinherited
hostNSU String
final
nsu String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
final
transactionCode String
final
transactionID String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited